hyperiax.models.prebuilts package
=================================

Submodules
----------

hyperiax.models.prebuilts.mean\_estimation module
-------------------------------------------------

.. automodule:: hyperiax.models.prebuilts.mean_estimation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hyperiax.models.prebuilts
   :members:
   :undoc-members:
   :show-inheritance:
